model WheelWithDryFriction "Example model of a wheel with dry friction"
  PlanarMechanics.Joints.Prismatic prismatic(r = {0, 1}, s(start = 1, fixed = true), v(fixed = true)) "Prismatic joint that allows the wheel to move toward or away from the center" annotation(Placement(transformation(extent = {{-10, -10}, {10, 10}}, rotation = 90)));
  PlanarMechanics.Joints.Revolute revolute(phi(fixed = true), w(fixed = true)) "Revolute joint with rotational axis around the z-axis" annotation(Placement(transformation(extent = {{-10, -10}, {10, 10}}, rotation = 90, origin = {0, -30})));
  PlanarMechanics.Parts.Fixed fixed "Fixed part to rotate around" annotation(Placement(transformation(extent = {{-10, -10}, {10, 10}}, rotation = 270, origin = {0, -60})));
  Modelica.Mechanics.Rotational.Sources.ConstantTorque engineTorque(tau_constant = inputTorque) "Simple engine, providing constant torque" annotation(Placement(transformation(extent = {{-32, 60}, {-12, 80}}, origin = {0, 0}, rotation = 0), visible = true));
  PlanarMechanics.Parts.Body body(m = 10, I = wheelInertia, animate = true) "Body to provide mass and inertia to the wheel" annotation(Placement(transformation(extent = {{20, 0}, {40, 20}}, origin = {0, 0}, rotation = 0), visible = true));
  PlanarMechanics.VehicleComponents.Wheels.DryFrictionWheelJoint dryFrictionWheelJoint(radius = 0.3, r = {1, 0}, N = normalForce, vAdhesion = vAdhesion, vSlide = vSlide, mu_A = mu_A, mu_S = mu_S, w_roll.fixed = false, w_roll.start = 10) "Component where friction dynamics are defined" annotation(Placement(transformation(extent = {{-10, -10}, {10, 10}}, rotation = 90, origin = {0, 32})));
  inner PlanarMechanics.PlanarWorld planarWorld(constantGravity = {0, 0}) annotation(Placement(transformation(extent = {{-80, -10}, {-60, 10}})));
  parameter Modelica.Units.SI.Force normalForce = 100 "Normal force affecting the wheel";
  parameter Modelica.Units.SI.Torque inputTorque = 2 "Torque applied on the wheel";
  parameter Modelica.Units.SI.Velocity vAdhesion = 0.1 "Adhesion velocity";
  parameter Modelica.Units.SI.Velocity vSlide = 0.3 "Sliding velocity";
  parameter Modelica.Units.SI.AbsoluteActivity mu_A = 0.8 "Friction coefficient at adhesion";
  parameter Modelica.Units.SI.AbsoluteActivity mu_S = 0.4 "Friction coefficient at sliding";
  parameter Modelica.Units.SI.Inertia wheelInertia = 1 "Inertia of the rolling wheel";
  Modelica.Mechanics.Rotational.Components.Inertia inertia(phi(fixed = true, start = 0), J = 1, w(start = 0, fixed = true)) "1-D rotational component with inertia" annotation(Placement(transformation(extent = {{-10, 10}, {10, -10}}, rotation = 270, origin = {-0, 60}), visible = true));
equation
  connect(prismatic.frame_a, revolute.frame_b) annotation(Line(points = {{0, -10}, {0, -10}, {0, -20}}, color = {95, 95, 95}, thickness = 0.5, visible = true));
  connect(revolute.frame_a, fixed.frame) annotation(Line(points = {{0, -40}, {0, -40}, {0, -50}}, color = {95, 95, 95}, thickness = 0.5, visible = true));
  connect(body.frame_a, prismatic.frame_b) annotation(Line(points = {{20, 10}, {0, 10}}, color = {95, 95, 95}, thickness = 0.5, visible = true));
  connect(dryFrictionWheelJoint.frame_a, prismatic.frame_b) annotation(Line(points = {{0, 27.2}, {0, 18.6}, {0, 18.6}, {0, 10}}, color = {95, 95, 95}, thickness = 0.5, visible = true));
  connect(dryFrictionWheelJoint.flange_a, inertia.flange_b) annotation(Line(points = {{0, 42}, {0, 42}, {0, 50}}, visible = true, color = {64, 64, 64}));
  connect(engineTorque.flange, inertia.flange_a) annotation(Line(points = {{-12, 70}, {0, 70}}, visible = true, color = {64, 64, 64}));
  annotation(preferredView = "info", uses(Modelica(version = "4.0.0"), PlanarMechanics(version = "1.6.0")), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {111, 0, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-90, -90}, {90, 90}}, radius = 25), Text(visible = true, origin = {12, 20.833}, textColor = {255, 255, 255}, extent = {{-102, -70.833}, {78, 29.167}}, textString = "Ex", fontName = "Arial")}), __Wolfram(openClass = WheelWithDryFriction, Animation(cameras = {Camera(name = "Default", center = {-0.02643631212413311, 0.02442489191889763, 0.03345969319343567}, distance = 5.354928645292019, rotation = {0, 0, 0, 1})}, windows = {Window(name = "Default", autoPlay = true, camera = "Default")}), ControlPanels(Panel(identifier = "nice-pythagoras", title = "Model parameters", elements = {InputField(variable = inputTorque, label = "Torque applied on the wheel"), InputField(variable = mu_A, label = "Friction coefficient at adhesion"), InputField(variable = mu_S, label = "Friction coefficient at sliding"), InputField(variable = normalForce, label = "Normal force affecting the wheel"), InputField(variable = vAdhesion, label = "Adhesion velocity"), InputField(variable = vSlide, label = "Sliding velocity"), InputField(variable = wheelInertia, label = "Inertia of the rolling wheel")}))), __Wolfram(PlotSet(plots = {Plot(name = "Position(parametricPlot)", preferred = true, subPlots = {SubPlot(curves = {Curve(x = body.r[1], y = body.r[2])})}), Plot(name = "WheelSlipVelocityAndAdhesionVelocity", subPlots = {SubPlot(curves = {Curve(x = time, y = dryFrictionWheelJoint.v_slip), Curve(x = time, y = dryFrictionWheelJoint.vAdhesion)})})})), experiment(StopTime = 20), Documentation(info = "<html>
<div style=\"background-color: #f4fbff; padding: 1rem; border: 2px solid #d9e5f3\">
<h2>Library Dependency</h2>
    <p class=\"\">
		This model requires the <a href=\"https://www.wolfram.com/system-modeler/libraries/planar-mechanics/\">PlanarMechanics</a> library.
	</p>
	<ul>
		<li style=\"background: url('modelica://EducationExamples/Resources/PlanarMechanics.png') no-repeat left top; background-size: 32px 32px; padding-left: 40px;\">The free PlanarMechanics library was created especially for modeling multibody systems with two-dimensional mechanical components. Compared to the MultiBody library, currently available in the Modelica Standard Library, it is simpler to use and it is more optimized to planar modeling. Planar models of mechanical systems are useful in many different applications, for example, in contact problems that are more easily modeled in 2D than in 3D.</li>

	</ul>
</div>

<h4>Model</h4>
    <p>
Although wheeled vehicles have been an important mode of transportation for more than 5,000 years, the dynamic behavior of wheel-surface interactions is still quite tricky to understand. Here, we study how a wheel modeled with dry friction behaves when driven with a constant torque around a pole. The <a href=\"modelica://PlanarMechanics\">Planar Mechanics Library</a> and <a href=\"modelica://Modelica\">Modelica Standard Library</a> have been used to create this model.
</p>
    <h4>Simulation</h4>
    <p>
To simulate the model and see the generated 3D animation, follow the steps below:
</p>
<p>Click the Simulate button: <img src=\"modelica://WheelWithDryFriction/DocumentationFiles/play.svg\" style=\"width:20px\" alt=\"\"/></p>
<p>When the simulation is finished, click the Animate button: <img src=\"modelica://WheelWithDryFriction/DocumentationFiles/animate.svg\" style=\"width:20px\" alt=\"animate\"/></p>

<p>Use your mouse or trackpad to drag the animation into a good angle and zoom in with your scroll wheel or by using the trackpad. Then click the Play button: <img src=\"modelica://WheelWithDryFriction/DocumentationFiles/play.svg\" style=\"width:20px\" alt=\"simPlay\"/></p>

<p style=\"text-align: center;\">
<img src=\"modelica://WheelWithDryFriction/DocumentationFiles/3Danimation.png\" style=\"width:470px\" alt=\"3Danimation\"/>
</p>
<p>
Above is an automatically generated 3D visualization of the model. To the left is the revolute joint fixed at a point in space. Attached to the revolute joint is a prismatic joint that leads to the wheel.
</p>
    <h4>Analysis</h4>
    <p>
When you have simulated the model, a Model plot will automatically be displayed, showing a parametric plot over the wheel position. Click on the other Model plots to see slip and adhesion velocities.
</p><p>
The first Model plot looks like this:
</p>
<p style=\"text-align: center;\"><img src=\"modelica://WheelWithDryFriction/DocumentationFiles/simCentPlotWheelPos.png\" style=\"width:480px\" alt=\"\" /></p>
<p>
In the parametric plot above, we can see the position of the wheel in a two-dimensional plane. As the wheel starts accelerating, the distance from the center will increase due to lateral slipping. Initially, this slipping is small, and the wheel moves in an almost ideal circle. However, as the slip velocity increases as a result of an increasing centrifugal force, the wheel starts to slide.
</p><p>
The second Model plot looks like this:
</p>
<p style=\"text-align: center;\"><img src=\"modelica://WheelWithDryFriction/DocumentationFiles/plotting2.png\" style=\"width:600px\" alt=\"\" /></p>
<p>
In the plot above, the slip velocity has been plotted against time to see when and how fast the wheel slipped.
</p><p>
The sliding of the wheel can be understood by studying the force of friction on the wheel as a function of slip velocity.
</p>
    <h4>Plotting and Further Analysis</h4>
    <p>
To further investigate this system, try changing some parameters in the model and see what happens. Interesting parameters to change are, for example, torque applied to the wheel, wheel radius, friction coefficients at adhesion or sliding, and so on. Investigate the result by plotting the plots above again but with other parameter values. Other interesting quantities are, for example, friction force versus slip velocity, or centrifugal force and friction force versus time.
</p>

<p>To create a new plot, click the toolbar icon: <img src=\"modelica://WheelWithDryFriction/DocumentationFiles/newplot.svg\" style=\"width:20px\" alt=\"PlotIcon\"/></p>

<p>To plot a variable, check its checkbox in the Plot window on the left in Simulation Center.</p>

<p>To create a new subplot, click the toolbar icon: <img src=\"modelica://WheelWithDryFriction/DocumentationFiles/addplot.svg\" style=\"width:20px\" alt=\"subPlotIcon\"/></p>
<p>To plot two variables against each other in a parametric plot, click the toolbar icon: <img src=\"modelica://WheelWithDryFriction/DocumentationFiles/plotparam.svg\" style=\"width:20px\" alt=\"PlotIcon2\"/> </p>

 <p>Check the checkboxes of the two variables to plot.</p>
<p>To change a parameter value, first click Parameters next to the Plot tab.</p>
<p>Change a parameter by opening up a tree in the Parameters view and changing the value for the parameter you want to change. Then run the simulation again.</p>
</html>", figures = {Figure(title = "Wheel position", identifier = "stoic-laplace", preferred = true, plots = {Plot(curves = {Curve(x = der(body.r[1]), y = der(body.r[2]), legend = "Wheel position")}, x = Axis(label = "x coordinate"), y = Axis(label = "y coordinate"))}), Figure(title = "Sliding velocity", identifier = "cool-wiles", plots = {Plot(title = "Slip velocity", curves = {Curve(y = vSlide, legend = "Sliding velocity"), Curve(y = dryFrictionWheelJoint.v_lat, legend = "Velocity in lateral direction")}, y = Axis(label = "Velocity"))})}));
end WheelWithDryFriction;
